================
Django Premailer
================

Django template tag that turns CSS blocks into style attributes using premailer_.

It supports Django 1.6+ for Python versions 2.7, 3.3, 3.4, 3.5 and pypy (where
the Django version supports the Python version).

.. image:: https://travis-ci.org/alexhayes/django-premailer.png?branch=master
    :target: https://travis-ci.org/alexhayes/django-premailer
    :alt: Build Status

.. image:: https://landscape.io/github/alexhayes/django-premailer/master/landscape.png
    :target: https://landscape.io/github/alexhayes/django-premailer/
    :alt: Code Health

.. image:: https://codecov.io/github/alexhayes/django-premailer/coverage.svg?branch=master
    :target: https://codecov.io/github/alexhayes/django-premailer?branch=master
    :alt: Code Coverage

.. image:: https://readthedocs.org/projects/django-premailer/badge/
    :target: http://django-premailer.readthedocs.org/en/latest/
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/django-premailer.svg
    :target: https://pypi.python.org/pypi/django-premailer
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/django-premailer.svg
    :target: https://pypi.python.org/pypi/django-premailer/
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/dd/django-premailer.svg
    :target: https://pypi.python.org/pypi/django-premailer/
    :alt: Downloads


Contents
--------

.. toctree::
 :maxdepth: 1

 installation
 usage
 developer
 internals/reference/index


License
-------

This software is licensed under the `MIT License`. See the `LICENSE`_.


Thanks
------

- Special thanks to http://roi.com.au for supporting the initial development of this project.
- Thanks to https://github.com/roverdotcom/django-inlinecss for initial inspiration.


Author
------

Alex Hayes <alex@alution.com>

.. _premailer: https://github.com/peterbe/premailer
.. _LICENSE: https://github.com/alexhayes/django-premailer/blob/master/LICENSE
